<!--
elisp manual generating stylesheet 
Author: Miloslav Nic (nicmila@systinet.com)
Copyright (C) 2001 Systinet

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details. 
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.

-->

 <xsl:stylesheet xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" version = "1.1" > 

   <xsl:output method="html" indent="yes"/>

   <xsl:param name="outDir">.</xsl:param>

   <xsl:key name="getSEC" match="*" use="@name"/>
   
   <xsl:variable name="indexLetters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
   <xsl:variable name="CSS">../CSS/style.css</xsl:variable>

   <xsl:template name="indexesList">
     <div>
       <b>&#160;&#160;&#160;Indexes:&#160;</b>
       <a href="functionIndex.html" class="jump">Functions</a>
       <b>&#160;/&#160;</b>
       <a href="variableIndex.html" class="jump">Variables</a>
       <b>&#160;/&#160;</b>
       <a href="commandIndex.html" class="jump">Commands</a>
       <b>&#160;/&#160;</b>
       <a href="specialFormIndex.html" class="jump">Forms</a>
       <b>&#160;/&#160;</b>
       <a href="userOptionIndex.html" class="jump">Options</a>
       <b>&#160;/&#160;</b>
       <a href="macroIndex.html" class="jump">Macros</a>
       <b>&#160;/&#160;</b>
       <a href="keywordIndex.html" class="jump">Keywords</a>
       <b>&#160;/&#160;</b>
       <a href="miscellaneous.html" class="jump">Misc</a>
     </div>
   </xsl:template>

   <xsl:template name="createFrameIndex">
     <xsl:param name="title"/>
     <xsl:param name="right"/>
     <html>
       <head>
	 <title>
	   <xsl:value-of select="$title"/>
	 </title>
       </head>
       <frameset cols='20%,*'>
	 <frame src="contents.html" name="mainIndex"/>
	 <frame src="{$right}" name="mainWindow"/>
       </frameset>
     </html>

   </xsl:template>

   <xsl:template name="indexToolbar">
     <xsl:param name="src"/>
     <xsl:param name="i" select="1"/>

          <!-- translate because of Snarf-documentation -->
     <xsl:if test="$src/a[$i]">
       <xsl:if test="translate(substring($src/a[$i],1,1),'S','s') != translate(substring($src/a[$i + 1],1,1),'S','s') and contains($indexLetters,substring($src/a[$i],1,1))">
	 <a class="jump" href="#{substring($src/a[$i],1,1)}">
	   <xsl:value-of select="substring($src/a[$i],1,1)"/>
	 </a>
	 <xsl:if test="$src/a[$i + 1]">
	   <xsl:text> - </xsl:text>
	 </xsl:if>
       </xsl:if>
       <xsl:call-template name="indexToolbar">
	 <xsl:with-param name="src" select="$src"/>
	 <xsl:with-param name="i" select="$i + 1"/>
       </xsl:call-template>
     </xsl:if>
   </xsl:template>


   <xsl:template name="index">
     <xsl:param name="title"/>
     <xsl:param name="src"/>
     <xsl:param name="i" select="1"/>
     <xsl:param name="i_letter" select="1"/>



     <xsl:if test="string-length($title) &gt; 0">
       <tr>
	 <th colspan="2">
	   <a name="top"/>
	   <h2>
	     <xsl:value-of select="$title"/>
	   </h2>
	 </th>
       </tr>
       <tr>
	 <td colspan="2">
	   <xsl:call-template name="indexToolbar">
	     <xsl:with-param name="src" select="$src"/>
	   </xsl:call-template>
	 </td>
       </tr>
       <xsl:if test="substring($src/a[$i],1,1) = '%'">
	 <tr>
	   <td colspan="2">&#160;</td>
	 </tr>
	 <tr>
	   <td colspan="2"><hr/></td>
	 </tr>
       </xsl:if>
     </xsl:if>

     <!-- translate because of Snarf-documentation -->
     <xsl:if test="substring($src/a[$i],1,1) = substring($indexLetters,$i_letter,1) and substring($src/a[$i],1,1) != translate(substring($src/a[$i - 1],1,1),'S','s') and contains($indexLetters,substring($src/a[$i],1,1))">

       <tr>
	 <td colspan="2">&#160;</td>
       </tr>
       <tr><td colspan="2"><hr/></td></tr>
       <tr>
	 <th colspan='2'>
	   <a name="{substring($src/a[$i],1,1)}"/>
	     <xsl:text> = </xsl:text>
	     <xsl:value-of select="substring($src/a[$i],1,1)"/>
	     <xsl:text> = </xsl:text>

	     <sup>
	       <a class = "jump" href="#top">top</a>
	     </sup>
	 </th>
       </tr>

     </xsl:if>

     <xsl:choose>
       <!-- translate because of Snarf-documentation -->
       <xsl:when test="not (contains($indexLetters,translate(substring($src/a[$i+1],1,1),'S','s')))">
	 <tr>
	   <td>&#160;<xsl:copy-of select="$src/a[$i]"/>&#160;</td>
	   <td>&#160;<xsl:copy-of select="$src/a[$i+1]"/>&#160;</td>
	 </tr>
	 <xsl:call-template name="index">
	   <xsl:with-param name="src" select="$src"/>
	   <xsl:with-param name="i" select="$i + 2"/>
	 </xsl:call-template>
       </xsl:when>

       <!-- translate because of Snarf-documentation -->
       <xsl:when test="not(contains($indexLetters,translate(substring($src/a[$i],1,1),'S','s')))">
	 <tr>
	   <td>&#160;<xsl:copy-of select="$src/a[$i]"/>&#160;</td>
	   <td></td>
	 </tr>

	 <xsl:call-template name="index">
	   <xsl:with-param name="src" select="$src"/>
	   <xsl:with-param name="i" select="$i + 1"/>
	 </xsl:call-template>
       </xsl:when>

       <!-- translate because of Snarf-documentation -->
       <xsl:when test="translate(substring($src/a[$i],1,1),'S','s') != substring($indexLetters,$i_letter,1) and substring($indexLetters,$i_letter,1) != 'z'">
	 <xsl:call-template name="index">
	   <xsl:with-param name="src" select="$src"/>
	   <xsl:with-param name="i" select="$i"/>
	   <xsl:with-param name="i_letter" select="$i_letter + 1"/>
	 </xsl:call-template>
       </xsl:when>

       <!-- translate because of Snarf-documentation -->

       <xsl:when test="translate(substring($src/a[$i+1],1,1),'S','s') = substring($indexLetters,$i_letter,1)">
	 <tr>
	   <td>&#160;<xsl:copy-of select="$src/a[$i]"/>&#160;</td>
	   <td>&#160;<xsl:copy-of select="$src/a[$i+1]"/>&#160;</td>
	 </tr>
	 <xsl:if test="$src/a[$i+2]">
	   <xsl:call-template name="index">
	     <xsl:with-param name="src" select="$src"/>
	     <xsl:with-param name="i" select="$i + 2"/>
	     <xsl:with-param name="i_letter" select="$i_letter"/>
	   </xsl:call-template>
	 </xsl:if>
       </xsl:when>

       <xsl:otherwise>
	 <tr>
	   <td>&#160;<xsl:copy-of select="$src/a[$i]"/>&#160;</td>
	   <td></td>
	 </tr>
	 <xsl:if test="$src/a[$i+1]">
	   <xsl:call-template name="index">
	     <xsl:with-param name="src" select="$src"/>
	     <xsl:with-param name="i" select="$i + 1"/>
	     <xsl:with-param name="i_letter" select="$i_letter"/>
	   </xsl:call-template>
	 </xsl:if>
       </xsl:otherwise>
     </xsl:choose>
   </xsl:template>


   <xsl:template name="createFilename">
     <xsl:param name="head"/>

     <xsl:choose>
       <xsl:when test="$head/a/@id">
	 <xsl:value-of select="$head/a/@id"/>
       </xsl:when>
       <xsl:otherwise>
	 <xsl:value-of select="translate(substring($head,0,15),' &#xA;','__')"/> 
       </xsl:otherwise>
     </xsl:choose>
     <xsl:text>.html</xsl:text>
   </xsl:template>

   <xsl:template match="/manual">
     <xsl:call-template name="createFrameIndex">
       <xsl:with-param name="title">elisp reference manual</xsl:with-param>
       <xsl:with-param name="right">
	 <xsl:call-template name="createFilename">
	   <xsl:with-param name="head" select="/manual/chapter[1]/h1"/>
	 </xsl:call-template>
       </xsl:with-param>
     </xsl:call-template>

     <xsl:document href="{$outDir}/search_index.html">
       <xsl:call-template name="createFrameIndex">
	 <xsl:with-param name="title">elisp reference manual</xsl:with-param>
	 <xsl:with-param name="right">../PHP/search.php</xsl:with-param>
       </xsl:call-template>
     </xsl:document>

     <xsl:document href="{$outDir}/GNU_Emacs_Lisp_index.html">
       <xsl:call-template name="createFrameIndex">
	 <xsl:with-param name="title">elisp reference manual</xsl:with-param>
	 <xsl:with-param name="right">GNU_Emacs_Lisp.html</xsl:with-param>
       </xsl:call-template>
     </xsl:document>

     <xsl:document href="{$outDir}/contents.html">
       <html>
	 <head>
	   <title>Contents</title>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	 </head>
	 <body>
	 
	   <table cellpadding="1" border="0">
	     <tr>
	       <td>
		 <a href="http://www.zvon.org/other/elisp/PHP/search.php" class="jump" target="mainWindow">
		   Search 
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td><hr/></td>
	     </tr>
	     <tr>
	       <td>
		 <a class="indexMenu" href="functionIndex.html" target="mainWindow">
		   Function Index
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td>
		 <a class="indexMenu" href="variableIndex.html" target="mainWindow">
		   Variable Index
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td>
		 <a class="indexMenu" href="commandIndex.html" target="mainWindow">
		   Command Index
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td>
		 <a class="indexMenu" href="specialFormIndex.html" target="mainWindow">
		   Special Form  Index
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td>
		 <a class="indexMenu" href="userOptionIndex.html" target="mainWindow">
		   User Option  Index
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td>
		 <a class="indexMenu" href="macroIndex.html" target="mainWindow">
		   Macro  Index
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td>
		 <a class="indexMenu" href="keywordIndex.html" target="mainWindow">
		   Keyword  Index
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td>
		 <a class="indexMenu" href="miscellaneous.html" target="mainWindow">
	       Miscellaneous
		 </a>
	       </td>
	     </tr>
	     <tr>
	       <td><hr/></td>
	     </tr>
	     <xsl:apply-templates select="chapter" mode="toc"/>
	   </table>
	 </body>
       </html>
 </xsl:document>

     <xsl:document href="{$outDir}/functionIndex.html">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>Function index</title>
	 </head>
 	 <body>
	   <table>
	     <xsl:call-template name="index">
	       <xsl:with-param name="title">Function index</xsl:with-param>
	       <xsl:with-param name="src">
		 <xsl:apply-templates select="//dt[u/text()='Function:']" mode="index">
		   <xsl:sort select="b"/>
		 </xsl:apply-templates>
	       </xsl:with-param>
	     </xsl:call-template>
	   </table>
	 </body>
       </html>
     </xsl:document>

     <xsl:document href="{$outDir}/variableIndex.html">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>Variable index</title>
	 </head>
	 <body>
	   <table>
	     <xsl:call-template name="index">
	       <xsl:with-param name="title">Variable index</xsl:with-param>
	       <xsl:with-param name="src">
		 <xsl:apply-templates select="//dt[u/text()='Variable:']" mode="index">
		   <xsl:sort select="b"/>
		 </xsl:apply-templates>
	       </xsl:with-param>
	     </xsl:call-template>
	   </table>
	 </body>
       </html>
     </xsl:document>

     <xsl:document href="{$outDir}/commandIndex.html">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>Command index</title>
	 </head>
	 <body>
	   <table>
	     <xsl:call-template name="index">
	       <xsl:with-param name="title">Command index</xsl:with-param>
	       <xsl:with-param name="src">
		 <xsl:apply-templates select="//dt[u/text()='Command:']" mode="index">
		   <xsl:sort select="b"/>
		 </xsl:apply-templates>
	       </xsl:with-param>
	     </xsl:call-template>
	   </table>
	 </body>
       </html>
     </xsl:document>

     <xsl:document href="{$outDir}/specialFormIndex.html">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>Special Form index</title>
	 </head>
	 <body>
	   <table>
	     <xsl:call-template name="index">
	       <xsl:with-param name="title">Special Form index</xsl:with-param>
	       <xsl:with-param name="src">
		 <xsl:apply-templates select="//dt[u/text()='Special Form:']" mode="index">
		   <xsl:sort select="b"/>
		 </xsl:apply-templates>
	       </xsl:with-param>
	     </xsl:call-template>
	   </table>
	 </body>
       </html>
     </xsl:document>

     <xsl:document href="{$outDir}/userOptionIndex.html">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>User Option index</title>
	 </head>
	 <body>
	   <table>
	     <xsl:call-template name="index">
	       <xsl:with-param name="title">User Option index</xsl:with-param>
	       <xsl:with-param name="src">
		 <xsl:apply-templates select="//dt[u/text()='User Option:']" mode="index">
		   <xsl:sort select="b"/>
		 </xsl:apply-templates>
	       </xsl:with-param>
	     </xsl:call-template>
	   </table>
	 </body>
       </html>
     </xsl:document>

     <xsl:document href="{$outDir}/macroIndex.html">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>Macro index</title>
	 </head>
	 <body>
	   <table>
	     <xsl:call-template name="index">
	       <xsl:with-param name="title">Macro index</xsl:with-param>
	       <xsl:with-param name="src">
		 <xsl:apply-templates select="//dt[u/text()='Macro:']" mode="index">
		   <xsl:sort select="b"/>
		 </xsl:apply-templates>
	       </xsl:with-param>
	     </xsl:call-template>
	   </table>
	 </body>
       </html>
     </xsl:document>

     <xsl:document href="{$outDir}/keywordIndex.html">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>Keyword index</title>
	 </head>
	 <body>
	   <table>
	     <xsl:call-template name="index">
	       <xsl:with-param name="title">Keyword index</xsl:with-param>
	       <xsl:with-param name="src">
		 <xsl:apply-templates select="//dt[substring(code,1,1)=':']" mode="index">
		   <xsl:sort select="substring(code,2)"/>
		 </xsl:apply-templates>
	       </xsl:with-param>
	     </xsl:call-template>
	   </table>
	 </body>
       </html>
     </xsl:document>

     <xsl:document href="{$outDir}/miscellaneous.html">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>Miscellaneous</title>
	 </head>
	 <body>
	     <h2>Miscellaneous</h2>
	     <p>
	       <xsl:apply-templates select="(descendant::dt[not(u)])[1]" mode="miscellaneous"/>
	     </p>
	 </body>
       </html>
     </xsl:document>

     <xsl:apply-templates select="chapter[1]" mode="titlePage"/>
     <xsl:apply-templates select="chapter[position() != 1]" mode="text"/>
   </xsl:template>


   <xsl:template match="chapter" mode="titlePage">
     <xsl:variable name="filename">
       <xsl:call-template name="createFilename">
	 <xsl:with-param name="head" select="h1"/>
       </xsl:call-template>
     </xsl:variable>

     <xsl:document href="{$outDir}/{$filename}">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>
	     <xsl:value-of select="h1"/>
	   </title>
	 </head>
	 <body>
	   <div>
	     <b>&#160;&#160;&#160;</b>
	     <a href="http://www.zvon.org/other/elisp/PHP/search.php" class="jump">Search </a>
	     <b>&#160;&#160;&#160;TOC:&#160;</b>
	     <a href="GNU_Emacs_Lisp_index.html" target="_top" class="jump">Show</a>
	     <b>&#160;/&#160;</b>
	     <a href="GNU_Emacs_Lisp.html" target="_top" class="jump">Hide</a>
	   </div>
	   <hr/>
	     <xsl:call-template name="indexesList"/>
	   <hr/>
	   <div>
       
	     <b>&#160;&#160;&#160;Next: </b>
	     <a class="indexMenu">
	       <xsl:attribute name="href">
		 <xsl:call-template name="createFilename">
		   <xsl:with-param name="head" select="following-sibling::*[1]/h1"/>
		 </xsl:call-template>
	       </xsl:attribute>
	       <xsl:value-of select="following-sibling::*/h1"/>
	     </a>
	   </div>
     <p>&#160;</p>
     <hr/>
     <xsl:copy-of select="node()"/>
	   
	   <p>&#160;</p>
	   <p>
	     This reference has been generated for <a href="http://www.zvon.org">Zvon</a> by <i>Miloslav Nic [<a href="mailto:nicmila@systinet.com">nicmila@systinet.com</a>]</i> from one web page manual available at <a href="http://www.gnu.org/manual/elisp-manual-20-2.5/elisp.html">http://www.gnu.org/manual/elisp-manual-20-2.5/elisp.html</a>. 
	   </p>
	   <p>
	     This manual can be downloaded for off-line use from <a href="http://zvon.org/index.php?nav_id=downloads">Zvon download page</a>, the search always leads to the <a href="http://www.zvon.org">Zvon site</a>. You can be also interested in our other materials targeted at <a href="http://zvon.org/o_html/group_programmers.html">programmers</a> and  <a href="http://zvon.org/o_html/group_xsl.html">XSL programmers</a>.
	   </p>
	   <p>
	     The original was transformed to XHTML using <a href="http://www.w3.org/People/Raggett/tidy/">Tidy</a> and then very slightly modified (head removed and added chapter elements). The source and XSLT stylesheet used to generate the manual is available in file <a href="elisp-manual.tar.gz">elisp-manual.tar.gz</a> and they can be used under <a href="SEC1.html">GPL license</a>. The stylesheet requires an XSLT processor supporting xsl:document element for multiple outputs (e.g. <a href="http://saxon.sourceforge.net/">Saxon</a>).
	   </p>

	   <p>
	     While this reference can be used in lynx, the version with TOC in the left frame is more convenient to use. If you need a frame enabled text WWW browser, I  recommend <a href="http://artax.karlin.mff.cuni.cz/~mikulas/links/">links</a>.
	   </p>
	 </body>
       </html>
     </xsl:document>
   </xsl:template>

   <xsl:template match="chapter" mode="toc">

     <tr>
       <td>
	 <b>
	   <xsl:value-of select="count(preceding-sibling::chapter)"/>
	   <xsl:text>. </xsl:text>
	 </b>
	 <a target="mainWindow">
	   <xsl:attribute name="href">
	     <xsl:call-template name="createFilename">
	       <xsl:with-param name="head" select="h1"/>
	     </xsl:call-template>
	   </xsl:attribute>
	   <xsl:value-of select="h1"/>
	 </a>
       </td>
     </tr>
   </xsl:template>

   <xsl:template name="chapterHeader">
     <xsl:param name="createFrameIndex" select="false()"/>
     <xsl:param name="filename"/>
     <xsl:variable name="frameindex">
       <xsl:value-of select="substring-before($filename, '.html')"/>
       <xsl:text>-index.html</xsl:text>
     </xsl:variable>
     
     <xsl:if test="$createFrameIndex">
       <xsl:document href="{$outDir}/{$frameindex}">
	 <xsl:call-template name="createFrameIndex">
	   <xsl:with-param name="title">elisp reference manual</xsl:with-param>
	   <xsl:with-param name="right" select="$filename"/>
	 </xsl:call-template>
       </xsl:document>
     </xsl:if>
     <hr/>
     <div>
       <b>&#160;&#160;&#160;</b>
       <a href="http://www.zvon.org/other/elisp/PHP/search.php" class="jump">Search </a>
       <b>&#160;&#160;&#160;TOC:&#160;</b>
       <a href="{$frameindex}" target="_top" class="jump">Show</a>
       <b>&#160;/&#160;</b>
       <a href="{$filename}" target="_top" class="jump">Hide</a>
     </div>
     <hr/>
     <xsl:call-template name="indexesList"/>

     <hr/>
     <div>
       <xsl:if test="following-sibling::*/h1">
	 <b>&#160;&#160;&#160;Next: </b>
	 <a class="indexMenu">
	   <xsl:attribute name="href">
	     <xsl:call-template name="createFilename">
	       <xsl:with-param name="head" select="following-sibling::*[1]/h1"/>
	     </xsl:call-template>
	   </xsl:attribute>
	   <xsl:value-of select="following-sibling::*/h1"/>
	 </a>
       </xsl:if>

       <xsl:if test="preceding-sibling::*/h1">
	 <b>&#160;&#160;&#160;Previous: </b>
	 <a class="indexMenu">
	   <xsl:attribute name="href">
	     <xsl:call-template name="createFilename">
	       <xsl:with-param name="head" select="preceding-sibling::*[1]/h1"/>
	     </xsl:call-template>
	   </xsl:attribute>
	   <xsl:value-of select="preceding-sibling::*[1]/h1"/>
	 </a>
	 <xsl:text>&#160;&#160;&#160;</xsl:text>
       </xsl:if>
     </div>
   </xsl:template>

   <xsl:template match="chapter" mode="text">
     
     <xsl:variable name="filename">
	 <xsl:call-template name="createFilename">
	   <xsl:with-param name="head" select="h1"/>
	 </xsl:call-template>
     </xsl:variable>

     <xsl:document href="{$outDir}/{$filename}">
       <html>
	 <head>
	   <link rel="stylesheet" type="text/css" href="{$CSS}"/>
	   <title>
	     <xsl:value-of select="h1"/>
	   </title>
	 </head>
	 <body>
	   <a name="top"/>
	   <a name="{h1/a/@name}"/>
	   <xsl:call-template name="chapterHeader">
	     <xsl:with-param name="filename" select="$filename"/>
	     <xsl:with-param name="createFrameIndex" select="true()"/>
	   </xsl:call-template>
	   <hr/>
	   <xsl:apply-templates mode="text"/>
	   <br/><hr/>
	   <xsl:call-template name="chapterHeader">
	     <xsl:with-param name="filename" select="$filename"/>
	   </xsl:call-template>
	 </body>
       </html>
     </xsl:document>
   </xsl:template>

   <xsl:template match="h1" mode="text">
     <h1>
       <xsl:value-of select="count(ancestor::chapter/preceding-sibling::chapter)"/>
       <xsl:text>. </xsl:text>
       <xsl:value-of select="."/>
     </h1>
     <ul>
       <xsl:apply-templates select="parent::*/h2" mode="jump"/>
     </ul>
     <hr/>
   </xsl:template>

   <xsl:template match="h2" mode="jump">
     <li>
       <a class="indexMenu" href="#{a/@name}">
	 <xsl:value-of select="."/>
       </a>
     </li>
   </xsl:template>

   <xsl:template match="h3" mode="jump">
     <li>
       <a class="indexMenu" href="#{a/@name}">
	 <xsl:value-of select="."/>
       </a>
     </li>
   </xsl:template>

   <xsl:template match="h3" mode="text">

     <a name="{a/@name}"/>
     <h3>

       <sup>
	 <a class="jump" href="#{preceding-sibling::h2[1]/a/@name}">top</a> 
       </sup>
       <xsl:text>&#160;</xsl:text>

       <xsl:value-of select="count(ancestor::chapter/preceding-sibling::chapter)"/>
       <xsl:text>.</xsl:text>

       <xsl:value-of select="count(preceding-sibling::h2[count(current()/ancestor::chapter | ancestor::chapter)=1])"/>
       <xsl:text>.</xsl:text>

       <xsl:value-of select="count(preceding-sibling::h3[count(current()/preceding-sibling::h2[1] | preceding-sibling::h2[1])=1]) + 1"/>
       <xsl:text>. </xsl:text>

       <xsl:value-of select="."/>

     </h3>
   </xsl:template>

   <xsl:template match="h2" mode="text">
     <a name="{a/@name}"/>
     <hr/>
     <h2>
       <sup>
	 <a class="jump" href="#top">top</a>
       </sup>
       
       <xsl:if test="following-sibling::h2[count(parent::* | current()/parent::*) = 1]">
	 <xsl:text>&#160;</xsl:text>
	 <sup>
	   <a class="jump" href="#{following-sibling::h2[1]/a/@name}">next</a>
	 </sup>
       </xsl:if>

       <xsl:if test="preceding-sibling::h2[count(parent::* | current()/parent::*) = 1]">
	 <xsl:text>&#160;</xsl:text>
	 <sup>
	   <a class="jump" href="#{preceding-sibling::h2[1]/a/@name}">prev</a>
	 </sup>
       </xsl:if>
       <br/>
              <xsl:value-of select="count(ancestor::chapter/preceding-sibling::chapter)"/>
       <xsl:text>.</xsl:text>

       <xsl:value-of select="count(preceding-sibling::h2[count(current()/ancestor::chapter | ancestor::chapter)=1]) + 1"/>
       <xsl:text>. </xsl:text>

       <xsl:value-of select="."/>
     </h2>

     <xsl:variable name="xxx">
       <xsl:apply-templates select="following-sibling::h3[count(preceding-sibling::h2[1] | current()) = 1]" mode="jump"/>
     </xsl:variable>
     <xsl:if test="$xxx/li">
       <ul>
	 <xsl:copy-of select="$xxx"/>
       </ul>
     </xsl:if>
   </xsl:template>

   <xsl:template match="h1" mode="changeLink">
     <xsl:call-template name="createFilename">
       <xsl:with-param name="head" select="."/>
     </xsl:call-template>
   </xsl:template>

   <xsl:template match="*" mode="changeLink">
     <xsl:call-template name="createFilename">
       <xsl:with-param name="head" select="ancestor::chapter/h1"/>
     </xsl:call-template>
   </xsl:template>

   <xsl:template match="a[@href]" mode="text">
     <xsl:choose>
       <xsl:when test="starts-with(@href,'elisp.html') or starts-with(@href,'#')">
	 <a class="indexMenu">
	   <xsl:attribute name="href">
	     <xsl:apply-templates select="key('getSEC',substring-after(@href,'#'))/parent::*" mode="changeLink"/>
	     <xsl:text>#</xsl:text>
	     <xsl:value-of select="substring-after(@href,'#')"/>
	   </xsl:attribute>
	   <xsl:value-of select="."/>
	 </a>
       </xsl:when>
       
       <xsl:otherwise>
	 <xsl:copy-of select="."/>
       </xsl:otherwise>
     </xsl:choose>
   </xsl:template>
   

   <xsl:template match="dt[not(ancestor::dd)]" mode="text">
     <dt>
       <a name="{following::dd[1]/a/@name}"/>
       <sup>
	 <a class="jump" href="#{(parent::*/preceding-sibling::h3[1]/a/@name | parent::*/preceding-sibling::h2[1]/a/@name | parent::*/preceding-sibling::h1[1]/a/@name)[last()]}">top</a>
       </sup>
       <xsl:apply-templates mode="text"/>
     </dt>
   </xsl:template>

   <xsl:template match="dd/a[not(@href)]" mode="text"/>

   <xsl:template match="dt" mode="index">
     <xsl:variable name="xxx">
       <xsl:call-template name="createFilename">
	 <xsl:with-param name="head" select="preceding::h1[1]"/>
       </xsl:call-template>
     </xsl:variable>
     
     <xsl:variable name="yyy">
       <xsl:choose>
	 <xsl:when test="following-sibling::*[1]/a/@name">
	   <xsl:value-of select="following-sibling::*[1]/a/@name"/>
	 </xsl:when>
	 <xsl:otherwise>
	   <xsl:value-of select="(preceding::h2[1]/a/@name | preceding::h3[1]/a/@name | preceding::h1[1]/a/@name)[last()]"/>
	 </xsl:otherwise>
       </xsl:choose>
      </xsl:variable>
      
     <a class="indexMenu" href="{$xxx}#{$yyy}">
       <xsl:value-of select="b|code/text()"/>
     </a>
     
   </xsl:template>

   <xsl:template match="dt" mode="miscellaneous">
     <xsl:param name="anchor"/>

     <xsl:choose>
       <xsl:when test="contains(.,'`') or contains(.,'%')">
	 <xsl:variable name="curAnchor" select="(preceding::h2[1]/a/@name | preceding::h3[1]/a/@name | preceding::h1[1]/a/@name)[last()]"/>

	 <xsl:if test="$anchor != $curAnchor">
	   <h3>
	     <xsl:value-of select="ancestor::chapter/h1[1]"/>
	     <xsl:text> / </xsl:text>
	     <xsl:value-of select="preceding::h2[count(ancestor::chapter | current()/ancestor::chapter) = 1][1]"/>
	     <xsl:text> / </xsl:text>
	     <xsl:value-of select="preceding::h3[count(preceding::h2[1] | current()/preceding::h2[1])=1][1]"/>
	   </h3>
	 </xsl:if>

	 <xsl:variable name="xxx">
	   <xsl:call-template name="createFilename">
	     <xsl:with-param name="head" select="parent::*/preceding::h1[1]"/>
	   </xsl:call-template>
	 </xsl:variable>

     
	 <xsl:text> | </xsl:text>
	 <a class="indexMenu" href="{$xxx}#{preceding::a[@name][1]/@name}">
	   <xsl:value-of select="."/>
	 </a>

	 <xsl:apply-templates select="following::dt[not(u)][1]" mode="miscellaneous">
	   <xsl:with-param name="anchor" select="$curAnchor"/>
	 </xsl:apply-templates>
       </xsl:when>
       <xsl:otherwise>
	 <xsl:apply-templates select="following::dt[not(u)][1]" mode="miscellaneous">
	   <xsl:with-param name="anchor" select="$anchor"/>
	 </xsl:apply-templates>
       </xsl:otherwise>
     </xsl:choose>
   </xsl:template>



   <xsl:template match="*"  mode="text">
     <xsl:copy>
       <xsl:copy-of select="@*"/>
       <xsl:apply-templates mode="text"/>
     </xsl:copy>
   </xsl:template>
</xsl:stylesheet> 











